#include "offset.h"
#include "ui_offset.h"

Offset::Offset(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Offset)
{
    ui->setupUi(this);

    this->setWindowTitle(APPLICATION_NAME " " VERSION);
    this->setFixedSize(312,121);

    connect(ui->pbStang, SIGNAL(clicked()), this, SLOT(stang_()));
    connect(ui->pbSet, SIGNAL(clicked()), this, SLOT(setOffset()));

    ui->lineDay->setInputMask("9999");
    ui->lineHour->setInputMask("99");
    ui->lineMinut->setInputMask("99");
    ui->lineSecond->setInputMask("99");

    ui->comboSign->addItem("+");
    ui->comboSign->addItem("-");

    QValidator *hourValidator = new QIntValidator(0, 24, this);
    QValidator *minSecValidator = new QIntValidator(0, 59, this);

    ui->lineHour->setValidator(hourValidator);
    ui->lineMinut->setValidator(minSecValidator);
    ui->lineSecond->setValidator(minSecValidator);

    QString conf_file_name = QDir::toNativeSeparators("/"PROG_NAME".conf");
    k = new Config(conf_file_name);
    std::string offs = k->getConf("offset");
    delete k;
    QString sec_in = QString::fromStdString(offs);
    qint64 sekunder = sec_in.toLongLong();

    if (sekunder < 0)
        ui->comboSign->setCurrentIndex(1);
    else
        ui->comboSign->setCurrentIndex(0);

    QString d,h,min,s;
    bool lyckas = MainWindow::getOffset(sec_in, d, h, min, s);

    if (lyckas)
    {

        ui->lineDay->setText(d);
        ui->lineHour->setText(h);
        ui->lineMinut->setText(min);
        ui->lineSecond->setText(s);

    }
    else
        QMessageBox::critical(this, APPLICATION_NAME " " VERSION,tr("No offset was calculated"));


}

Offset::~Offset()
{








    delete ui;

}
// SLOTS
void Offset::setOffset()
{

    QString day = ui->lineDay->text();
    QString hour = ui->lineHour->text();
    QString minut = ui->lineMinut->text();
    QString sek = ui->lineSecond->text();

    int i_day = day.toInt();
    int i_hour = hour.toInt();
    int i_minut = minut.toInt();
    int i_sek = sek.toInt();

    quint64 allsek = i_day * 86400;
    allsek = allsek + (i_hour * 3600);
    allsek = allsek + (i_minut * 60);
    allsek = allsek + i_sek;


    QString allqs;
    allqs.setNum(allsek);

    if (ui->comboSign->currentIndex() == 1)
        allqs="-"+allqs;

    std::string alls = allqs.toStdString();



    QString conf_file_name = QDir::toNativeSeparators("/"PROG_NAME".conf");
    k = new Config(conf_file_name);
    k->setConf("offset",alls);
    delete k;


}

void Offset::stang_()
{

delete this;


}


void Offset::closeEvent(QCloseEvent * event)
{



delete this;

}
